@extends('layouts.hcp')
@section('content')

<div class="bg-light">
    <div class="container pt-3">
        <nav class="mb-0">
            <ol class="breadcrumb">
                <li class="breadcrumb-item"><a href="{{route('index')}}"><u>Home</u></a></li>
                <li class="breadcrumb-item"><a href="{{route('hcp.index')}}"><u>Healthcare Professionals</u></a></li>
                <li class="breadcrumb-item"><a href="{{route('hcp.order-products')}}"><u>Order Products</u></a></li>
                <li class="breadcrumb-item active" aria-current="page">Marketing Materials</li>
            </ol>
        </nav>
    </div>
</div>

<div class="bg-grey py-5">
  <div class="container">
    <div class="row justify-content-center">
      <div class="col-lg-7 text-center">
        <h5 class="title m-0">Marketing Materials</h5>
      </div>
    </div>
  </div>
</div>

<div class="container py-5">
  <div class="row">
    <div class="col-lg-3 d-lg-block d-none">
      @include('app.hcp.order-products.sidenav')
    </div>
    <div class="col-lg-8">
      <h4 class="header">Marketing Materials for Your Practice</h4>
      <p class="mt-4">We know that marketing materials are a huge asset in helping patients and staff understand the Snyder HemBand procedure. Because of this, we’re happy to provide a variety of marketing materials at no cost to you or your practice.</p>
      <p>To place an order, please fill out the form below or submit an order form via fax or email <a href="mailto:support@hemband.com">support@hemband.com</a>.</p>
      <div class="bg-light p-4">
        <form class="" action="{{ route('hcp.submit-order-products-marketing') }}" method="post" autocomplete="off">
          @csrf
          <div class="row">
            <div class="col-12">
              @if($errors->any())
                <div class="alert alert-danger fade show" role="alert">
                  There were errors found!
                </div>
              @endif
              @if(session('success'))
                <div class="alert alert-success fade show" role="alert">
                  {{session('success')}}
                </div>
              @endif
            </div>
            <div class="col-lg-6 form-group mb-4">
              <label>First Name <span class="text-danger">*</span> </label>
              <input type="text" class="form-control rounded-0 py-3" required name="name_first" value="{{ old('name_first') }}">
              @error('name_first')
                <small class="text-warning">{{$message}}</small>
              @enderror
            </div>
            <div class="col-lg-6 form-group mb-4">
              <label>Last Name <span class="text-danger">*</span> </label>
              <input type="text" class="form-control rounded-0 py-3" required name="name_last" value="{{ old('name_last') }}">
              @error('name_last')
                <small class="text-warning">{{$message}}</small>
              @enderror
            </div>
          </div>
          <div class="form-group mb-4">
            <label>Title <span class="text-danger">*</span> </label>
            <input type="text" class="form-control rounded-0 py-3" required name="title" value="{{ old('title') }}">
            @error('title')
                <small class="text-warning">{{$message}}</small>
              @enderror
          </div>
          <div class="row">
            <div class="col-lg-4 form-group mb-4">
              <label>Practice Name <span class="text-danger">*</span> </label>
              <input type="text" class="form-control rounded-0 py-3" required name="practice_name" value="{{ old('practice_name') }}">
              @error('practice_name')
                <small class="text-warning">{{$message}}</small>
              @enderror
            </div>
            <div class="col-lg-5 form-group mb-4">
              <label>Practice Address <span class="text-danger">*</span> </label>
              <input type="text" class="form-control rounded-0 py-3" required name="practice_address" value="{{ old('practice_address') }}">
              @error('practice_address')
                <small class="text-warning">{{$message}}</small>
              @enderror
            </div>
            <div class="col-lg-3 form-group mb-4">
              <label>Practice Zip Code <span class="text-danger">*</span> </label>
              <input type="text" class="form-control rounded-0 py-3 zip" required name="zip" value="{{ old('zip') }}">
              @error('zip')
                <small class="text-warning">{{$message}}</small>
              @enderror
            </div>
          </div>
          <div class="row">
            <div class="col-lg-6 form-group mb-4">
              <label>Contact Phone Number <span class="text-danger">*</span> </label>
              <input type="tel" class="form-control rounded-0 py-3 phone" required name="phone" value="{{ old('phone') }}">
              @error('phone')
                <small class="text-warning">{{$message}}</small>
              @enderror
            </div>
            <div class="col-lg-6 form-group mb-4">
              <label>Contact Email <span class="text-danger">*</span> </label>
              <input type="email" class="form-control rounded-0 py-3" required name="email" value="{{ old('email') }}">
              @error('email')
                <small class="text-warning">{{$message}}</small>
              @enderror
            </div>
          </div>
          <div class="form-group mb-4">
            <label>Order request</label>
            <textarea name="comment" class="form-control rounded-0" rows="6">{{ old('comment') }}</textarea>
              @error('comment')
                <small class="text-warning">{{$message}}</small>
              @enderror
          </div>
          <div class="form-group mb-4">
            {!! htmlFormSnippet() !!}
            @error('g-recaptcha-response')
              <small class="text-danger"><i class="fas fa-exclamation-triangle mr-2"></i>Invalid</small>
            @enderror
          </div>
          <button type="submit" class="btn btn-pry w-100 py-3">SUBMIT</button>
        </form>
      </div>
      {{--
      <div class="divider my-4"></div>
      <div class="row align-items-center">
        <div class="col-lg-2">
          <a href="#"><img  src="{{asset('img/ligators.jpeg')}}" class="w-75 border border-dark" alt=""> </a>
        </div>
        <div class="col-lg-10">
          <h5 class="header">Patient Education Materials</h5>
        </div>
      </div>
      <div class="divider my-4"></div>
      <div class="row align-items-center">
        <div class="col-lg-2">
          <a href="#"><img  src="{{asset('img/ligators.jpeg')}}" class="w-75 border border-dark" alt=""> </a>
        </div>
        <div class="col-lg-10">
          <h5 class="header">Referring Physician Materials</h5>
        </div>
      </div>
      <div class="divider my-4"></div>
      <div class="row align-items-center">
        <div class="col-lg-2">
          <a href="#"><img  src="{{asset('img/ligators.jpeg')}}" class="w-75 border border-dark" alt=""> </a>
        </div>
        <div class="col-lg-10">
          <h5 class="header">Advertising Templates</h5>
        </div>
      </div>
      <div class="divider my-4"></div>
      <div class="row align-items-center">
        <div class="col-lg-2">
          <a href="#"><img  src="{{asset('img/ligators.jpeg')}}" class="w-75 border border-dark" alt=""> </a>
        </div>
        <div class="col-lg-10">
          <h5 class="header">Symptom Questionnaire Form</h5>
        </div>
      </div>
        --}}
    </div>
  </div>
</div>

@endsection
