@extends('layouts.hcp')
@section('content')

<div class="bg-light">
    <div class="container pt-3">
        <nav class="mb-0">
            <ol class="breadcrumb">
                <li class="breadcrumb-item"><a href="{{route('index')}}"><u>Home</u></a></li>
                <li class="breadcrumb-item"><a href="{{route('hcp.index')}}"><u>Healthcare Professionals</u></a></li>
                <li class="breadcrumb-item"><a href="{{route('hcp.practice-support')}}"><u>Practice Support</u></a></li>
                <li class="breadcrumb-item active" aria-current="page">Reimbursement-Guide</li>
            </ol>
        </nav>
    </div>
</div>
<div class="py-5">
  <div class="container py-lg-4">
    <div class="row justify-content-center">
      <div class="col-lg-5 text-start">
        <h5 class="subtitle mb-4 text-pry">Hemorrhoid Banding CPT Code</h5>
        <p>Hemorrhoid banding is typically billed using CPT code 46221.</p>

<p>This service should be reported and billed on each service, regardless of how many hemorrhoid bands are used.</p>

For questions regarding billing, please contact our support team at: <a href="tel:{{config('app.contactPhoneNumber')}}">{{config('app.contactPhoneNumber')}}</a> or email <a href="mailto:{{ config('app.supportEmailAddress') }}">{{ config('app.supportEmailAddress') }}</a></p>
      </div>
      <div class="col-lg-6 offset-lg-1">
        <img src="{{asset('img/reimburse.jpg')}}" class="w-100" alt="">
      </div>
    </div>
  </div>
</div>

{{--
<div class="bg-light">
<div class="container py-5">
    <div class="row text-justify">
      <div class="col-lg-6">
        <div class="mb-4">
          <h5 class="header">Primary Hemorrhoid Banding CPT Code</h5>
          <p>The main hemorrhoid banding CPT code that you need to know is 46221. If you use a disposable ligator like the <a href="https://www.adlermicromed.com/al9000/the-adler-ligator-hemorrhoid-banding-information/">Adler ligator</a>, then that’s the code that you will use. The <a href="https://www.cookmedical.com/wp-content/uploads/2020/01/RG_ESC_50058_RE_202002.pdf">procedure description</a> that goes along with code 46221 is “Hemorrhoidectomy, internal, by rubber band ligation(s).”</p>
          <p>You might think of a hemorrhoidectomy as a full surgical removal procedure that involves cutting or stitching. That’s not what rubber band ligation involves, of course. Even still, this code description makes sense since the intent of banding is to remove the hemorrhoid from the body.</p>
        </div>
        <div class="mb-4">
          <h5 class="header">Additional CPT Codes to Know</h5>
          <p>There are a few other CPT codes that can be used for hemorrhoid banding in some cases. The main situation in which you might need a different code is when ligation is performed with a flexible scope instead of a rigid one.</p>
          <p>For example, when hemorrhoid banding is <a href="https://www.asge.org/docs/default-source/coding/colonoscopy_2018-coding-sheet.pdf?sfvrsn=3a2ca050_4">performed during a colonoscopy</a>, you should put down code 45298. The description for that code is “Colonoscopy, flexible; with band ligation(s) (eg, hemorrhoids)." If the accompanying procedure is a sigmoidoscopy, then the code is 45350. Its description is “Sigmoidoscopy, flexible; with band ligation(s) (eg, hemorrhoids).”</p>
          <p>However, if the banding is performed with a rigid scope, you will stick with code 46221. Typically, anoscopy is considered <a href="https://www.inxmedical.com/wp-content/uploads/2017/02/Reimbursement-Guide-2016.pdf">part of the banding service</a> and not a separate charge. Billing separately for the scope should only be done if it has a distinct purpose, such as diagnosing a different condition.</p>
          <p>If you have a situation in which it seems appropriate to list both the scoping and banding procedures, then you should use 46600 for anoscopy or 45300 for proctoscopy. For either one, including modifier 59 is essential.</p>
        </div>
        <div class="mb-4">
          <h5 class="header">Office Visit Coding</h5>
          <p>You may have a new patient who would benefit from immediate in-office hemorrhoid banding. In that case, you can charge for both the new-patient visit and the treatment procedure. It’s a good idea to add modifier 25 to increase the chances that the payer will accept both codes.</p>
          <p>When an established patient comes to the office solely for hemorrhoid treatment, you should not bill separately for the visit. The time spent with the patient to discuss and treat the hemorrhoids is included in the 46221 code. You cannot add a separate evaluation and management (E/M) code in addition to the ligation one.</p>
          <p>The exception to this rule is when a patient has more than one colorectal concern to discuss with you. Some of the people you see may be dealing with more than just hemorrhoids. If you use modifier 25, you can report codes for both conditions that you evaluate or treat that day.</p>
          <p>Examples of additional issues that might qualify for separate billing include:</p>
          <ul>
            <li>Anal fissures</li>
            <li>Bowel irregularities</li>
            <li>Yeast infections</li>
          </ul>
        </div>
      </div>
      <div class="col-lg-6">
        <div class="mb-4">
          <h5 class="header">Multiple Procedures and Global Periods</h5>
          <p>It’s common for a person with hemorrhoids to have multiple sites that require treatment. Some doctors place multiple bands during one ligation session. Others allow time for the patient to rest and recover before coming back for a second procedure.</p>
          <p>One reason to spread the treatments out is to keep the process simple. For in-office procedures, you shouldn’t address more than two hemorrhoids at a time. If you plan to band three or more areas, it should be done in a surgical center with anesthesia. In addition, success rates may improve when only one hemorrhoid is banded at a time.</p>
          <p>Billing is another reason to treat each hemorrhoid separately. Even if you band two hemorrhoids on the same day, you can only list the hemorrhoid banding CPT code 46221 once.</p>
          <p>However, if you treat each hemorrhoid on a separate day, then you can bill for each of the sessions. If you want to increase your reimbursement, then having the patient come back in a few weeks is the way to go.</p>
          <p>As you consider when to schedule the next ligation session, keep in mind that hemorrhoid ligation banding has a <a href="https://www.cms.gov/Outreach-and-Education/Medicare-Learning-Network-MLN/MLNProducts/downloads/GloballSurgery-ICN907166.pdf">global period of 10 days</a>. The countdown begins the day after surgery.</p>
          <p>To ensure that you’ll be able to bill a second treatment separately, most experts recommend scheduling it two weeks after the first. 12 days should be the absolute minimum.</p>
        </div>
        <div class="mb-4">
          <h5 class="header">Get Started with Hemorrhoid Ligation</h5>
          <p>Learning the correct hemorrhoid banding CPT code for each situation is one of the most complicated things about this procedure. Compared to figuring out the right codes, the choice to use disposable hemorrhoid ligators in your practice should be an easy one.</p>
          <p>For more information on the Adler Ligator (AL9000) and its many benefits, consult Adler MicroMed’s <a href="https://www.adlermicromed.com/al9000/">resource page</a> or <a href="{{route('hcp.contact-us')}}">reach out with your questions</a>.</p>
          <p>As with all medical issues, your physician is the ultimate source as to what procedure best fits your needs. Discuss all options and get a second opinion if you have any doubts. These articles are intended to be a source of general information only.</p>
        </div>
      </div>
    </div>
  </div>
</div>
--}}

@endsection
